API extended to support fractions of seconds

diff --git a/skeletons/GeneralizedTime.h b/skeletons/GeneralizedTime.h
index 21a680c..90f7e08 100644
--- a/skeletons/GeneralizedTime.h
+++ b/skeletons/GeneralizedTime.h
@@ -32,14 +32,21 @@
 time_t asn_GT2time(const GeneralizedTime_t *, struct tm *_optional_tm4fill,
 	int as_gmt);
 
+/* A version of the above function also returning the fractions of seconds */
+time_t asn_GT2time_frac(const GeneralizedTime_t *,
+	long *frac_value, long *frac_base,		/* (value/base) */
+	struct tm *_optional_tm4fill, int as_gmt);
+
 /*
  * Convert a struct tm into GeneralizedTime.
  * If __opt_gt is not given, this function will try to allocate one.
  * If force_gmt is given, the resulting GeneralizedTime will be forced
  * into a GMT time zone (encoding ends with a "Z").
  * On error, this function returns 0 and sets errno.
  */
-GeneralizedTime_t *asn_time2GT(GeneralizedTime_t *__opt_gt, const struct tm *,
-	int force_gmt);
+GeneralizedTime_t *asn_time2GT(GeneralizedTime_t *_optional_gt,
+	const struct tm *, int force_gmt);
+GeneralizedTime_t *asn_time2GT_frac(GeneralizedTime_t *_optional_gt,
+	const struct tm *, long frac_value, long frac_base, int force_gmt);
 
 #endif	/* _GeneralizedTime_H_ */
@@ -32,14 +32,21 @@
 /*
  * Convert a struct tm into GeneralizedTime.
- * If __opt_gt is not given, this function will try to allocate one.
+ * If _optional_gt is not given, this function will try to allocate one.
  * If force_gmt is given, the resulting GeneralizedTime will be forced
  * into a GMT time zone (encoding ends with a "Z").